Conversation
^^^^^^^^^^^^

Conversation exchange has following steps:

#. send "Message" to SFChat server
#. start "Long pulling" to get new messages and show them
#. remove from server all successfully delivered messages
